@@ -10,7 +10,6 @@
 
 #include "pyglib.h"
 #include "pyglib-private.h"
-#include "pygsource.h"
 
 typedef struct {
     PyObject_HEAD
@@ -18,8 +17,6 @@ typedef struct {
     int softspace;         /* to make print >> chan, "foo" ... work */
 } PyGIOChannel;
 
-PYGLIB_DEFINE_TYPE("glib.IOChannel", PyGIOChannel_Type, PyGIOChannel)
-
 static PyObject*
 py_io_channel_next(PyGIOChannel *self)
 {
@@ -39,23 +36,18 @@ py_io_channel_next(PyGIOChannel *self)
         return NULL;
     }
 
-    ret_obj = PYGLIB_PyUnicode_FromStringAndSize(str_return, length);
+    ret_obj = PyString_FromStringAndSize(str_return, length);
     g_free(str_return);
     return ret_obj;
+
 }
 
-static PyObject*
-py_io_channel_richcompare(PyObject *self, PyObject *other, int op)
+static int
+py_io_channel_compare(PyGIOChannel *self, PyGIOChannel *v)
 {
-    if (Py_TYPE(self) == Py_TYPE(other) && 
-          Py_TYPE(self) == &PyGIOChannel_Type) {
-        return _pyglib_generic_ptr_richcompare(((PyGIOChannel*)self)->channel,
-                                               ((PyGIOChannel*)other)->channel,
-                                               op);
-    } else {
-       Py_INCREF(Py_NotImplemented);
-       return Py_NotImplemented;
-    }
+    if (self->channel == v->channel) return 0;
+    if (self->channel > v->channel) return -1;
+    return 1;
 }
 
 static PyObject*
@@ -87,14 +79,14 @@ py_io_channel_shutdown(PyGIOChannel* self, PyObject *args, PyObject *kwargs)
     PyObject* flush = Py_True;
     GError* error = NULL;
 
-    if (!PyArg_ParseTupleAndKeywords(args, kwargs, "|O:glib.IOChannel.shutdown", kwlist, &flush))
+    if (!PyArg_ParseTupleAndKeywords(args, kwargs, "|O:gobject.IOChannel.shutdown", kwlist, &flush))
         return NULL;
 	
     ret = g_io_channel_shutdown(self->channel, PyObject_IsTrue(flush), &error);
     if (pyglib_error_check(&error))
 	return NULL;
 	
-    return PYGLIB_PyLong_FromLong(ret);
+    return PyInt_FromLong(ret);
 }
 
 /* character encoding conversion involved functions.
@@ -106,7 +98,7 @@ py_io_channel_set_buffer_size(PyGIOChannel* self, PyObject *args, PyObject *kwar
     static char *kwlist[] = { "size", NULL };
     int size;
 
-    if (!PyArg_ParseTupleAndKeywords(args, kwargs, "i:glib.IOChannel.set_buffer_size", kwlist, &size))
+    if (!PyArg_ParseTupleAndKeywords(args, kwargs, "i:gobject.IOChannel.set_buffer_size", kwlist, &size))
         return NULL;
 	
     g_io_channel_set_buffer_size(self->channel, size);
@@ -116,9 +108,17 @@ py_io_channel_set_buffer_size(PyGIOChannel* self, PyObject *args, PyObject *kwar
 }
 
 static PyObject*
-py_io_channel_get_buffer_size(PyGIOChannel* self)
+py_io_channel_get_buffer_size(PyGIOChannel* self, PyObject *args, PyObject *kwargs)
 {
-    return PYGLIB_PyLong_FromLong(g_io_channel_get_buffer_size(self->channel));
+    static char *kwlist[] = { NULL };
+    int size;
+
+    if (!PyArg_ParseTupleAndKeywords(args, kwargs, "i:gobject.IOChannel.get_buffer_size", kwlist))
+        return NULL;
+	
+    size = g_io_channel_get_buffer_size(self->channel);
+    
+    return PyInt_FromLong(size);
 }
 
 static PyObject*
@@ -127,7 +127,7 @@ py_io_channel_set_buffered(PyGIOChannel* self, PyObject *args, PyObject *kwargs)
     static char *kwlist[] = { "buffered", NULL };
     int buffered;
 
-    if (!PyArg_ParseTupleAndKeywords(args, kwargs, "i:glib.IOChannel.set_buffered", kwlist, &buffered))
+    if (!PyArg_ParseTupleAndKeywords(args, kwargs, "i:gobject.IOChannel.set_buffered", kwlist, &buffered))
         return NULL;
 	
     g_io_channel_set_buffered(self->channel, buffered);
@@ -137,9 +137,17 @@ py_io_channel_set_buffered(PyGIOChannel* self, PyObject *args, PyObject *kwargs)
 }
 
 static PyObject*
-py_io_channel_get_buffered(PyGIOChannel* self)
+py_io_channel_get_buffered(PyGIOChannel* self, PyObject *args, PyObject *kwargs)
 {
-    return PYGLIB_PyLong_FromLong(g_io_channel_get_buffered(self->channel));
+    static char *kwlist[] = { NULL };
+    int buffered;
+
+    if (!PyArg_ParseTupleAndKeywords(args, kwargs, ":gobject.IOChannel.get_buffered", kwlist))
+        return NULL;
+	
+    buffered = g_io_channel_get_buffered(self->channel);
+    
+    return PyInt_FromLong(buffered);
 }
 
 static PyObject*
@@ -149,7 +157,7 @@ py_io_channel_set_encoding(PyGIOChannel* self, PyObject *args, PyObject *kwargs)
     const char* encoding;
     GError* error = NULL;
     
-    if (!PyArg_ParseTupleAndKeywords(args, kwargs, "z:glib.IOChannel.set_encoding", kwlist, &encoding))
+    if (!PyArg_ParseTupleAndKeywords(args, kwargs, "z:gobject.IOChannel.set_encoding", kwlist, &encoding))
         return NULL;
     
     g_io_channel_set_encoding(self->channel, encoding, &error);
@@ -161,16 +169,22 @@ py_io_channel_set_encoding(PyGIOChannel* self, PyObject *args, PyObject *kwargs)
 }
 
 static PyObject*
-py_io_channel_get_encoding(PyGIOChannel* self)
+py_io_channel_get_encoding(PyGIOChannel* self, PyObject *args, PyObject *kwargs)
 {
-    const char* encoding = g_io_channel_get_encoding(self->channel);
+    static char *kwlist[] = { NULL };
+    const char* encoding;
+
+    if (!PyArg_ParseTupleAndKeywords(args, kwargs, ":gobject.IOChannel.get_encoding", kwlist))
+        return NULL;
+	
+    encoding = g_io_channel_get_encoding(self->channel);
     
     if (encoding == NULL) {
 	Py_INCREF(Py_None);
 	return Py_None;
     }
 
-    return PYGLIB_PyUnicode_FromString(encoding);
+    return PyString_FromString(encoding);
 }
 
 #define CHUNK_SIZE (8 * 1024)
@@ -185,11 +199,11 @@ py_io_channel_read_chars(PyGIOChannel* self, PyObject *args, PyObject *kwargs)
     GError* error = NULL;
     GIOStatus status = G_IO_STATUS_NORMAL;
 
-    if (!PyArg_ParseTupleAndKeywords(args, kwargs, "|i:glib.IOChannel.read", kwlist, &max_count))
+    if (!PyArg_ParseTupleAndKeywords(args, kwargs, "|i:gobject.IOChannel.read", kwlist, &max_count))
         return NULL;
 	
     if (max_count == 0)
-	return PYGLIB_PyUnicode_FromString("");
+	return PyString_FromString("");
     
     while (status == G_IO_STATUS_NORMAL
 	   && (max_count == -1 || total_read < max_count)) {
@@ -206,16 +220,16 @@ py_io_channel_read_chars(PyGIOChannel* self, PyObject *args, PyObject *kwargs)
         }
 	
 	if ( ret_obj == NULL ) {
-	    ret_obj = PYGLIB_PyBytes_FromStringAndSize((char *)NULL, buf_size);
+	    ret_obj = PyString_FromStringAndSize((char *)NULL, buf_size);
 	    if (ret_obj == NULL)
 		goto failure;
 	}
-	else if (buf_size + total_read > PYGLIB_PyBytes_Size(ret_obj)) {
-	    if (PYGLIB_PyBytes_Resize(&ret_obj, buf_size + total_read) == -1)
+	else if (buf_size + total_read > PyString_GET_SIZE(ret_obj)) {
+	    if (_PyString_Resize(&ret_obj, buf_size + total_read) == -1)
 		goto failure;
 	}
        
-        buf = PYGLIB_PyBytes_AsString(ret_obj) + total_read;
+        buf = PyString_AS_STRING(ret_obj) + total_read;
 
         pyglib_unblock_threads();
         status = g_io_channel_read_chars(self->channel, buf, buf_size, 
@@ -227,28 +241,10 @@ py_io_channel_read_chars(PyGIOChannel* self, PyObject *args, PyObject *kwargs)
 	total_read += single_read;
     }
 	
-    if ( total_read != PYGLIB_PyBytes_Size(ret_obj) ) {
-	if (PYGLIB_PyBytes_Resize(&ret_obj, total_read) == -1)
+    if ( total_read != PyString_GET_SIZE(ret_obj) ) {
+	if (_PyString_Resize(&ret_obj, total_read) == -1)
 	    goto failure;
     }
-
-#if PY_VERSION_HEX >= 0x03000000
-    /* If this is not UTF8 encoded channel return the raw bytes */
-    if (g_io_channel_get_encoding(self->channel) != NULL)
-        return ret_obj;
-
-    /* convert to Unicode string */
-    {
-	PyObject *unicode_obj;
-
-	unicode_obj = PyUnicode_FromString(PyBytes_AS_STRING(ret_obj));
-	if (unicode_obj == NULL)
-	    goto failure;
-	Py_DECREF(ret_obj);
-	ret_obj = unicode_obj;
-    }
-#endif
-
     return ret_obj;
 
   failure:
@@ -266,7 +262,7 @@ py_io_channel_write_chars(PyGIOChannel* self, PyObject *args, PyObject *kwargs)
     GError* error = NULL;
     GIOStatus status;
 
-    if (!PyArg_ParseTupleAndKeywords(args, kwargs, "s#:glib.IOChannel.write",
+    if (!PyArg_ParseTupleAndKeywords(args, kwargs, "s#:gobject.IOChannel.write",
                                      kwlist, &buf, &buf_len))
         return NULL;
 	
@@ -276,7 +272,7 @@ py_io_channel_write_chars(PyGIOChannel* self, PyObject *args, PyObject *kwargs)
     if (pyglib_error_check(&error))
 	return NULL;
 	
-    return PYGLIB_PyLong_FromLong(count);
+    return PyInt_FromLong(count);
 }
 
 static PyObject*
@@ -290,7 +286,7 @@ py_io_channel_write_lines(PyGIOChannel* self, PyObject *args, PyObject *kwargs)
     GIOStatus status;
     PyObject *iter, *value, *pylines;
 
-    if (!PyArg_ParseTupleAndKeywords(args, kwargs, "O:glib.IOChannel.writelines",
+    if (!PyArg_ParseTupleAndKeywords(args, kwargs, "O:gobject.IOChannel.writelines",
                                      kwlist, &pylines))
         return NULL;
 
@@ -302,13 +298,13 @@ py_io_channel_write_lines(PyGIOChannel* self, PyObject *args, PyObject *kwargs)
             PyErr_Clear();
             goto normal_exit;
         }
-        if (!PYGLIB_PyUnicode_Check(value)) {
-            PyErr_SetString(PyExc_TypeError, "glib.IOChannel.writelines must"
+        if (!PyString_Check(value)) {
+            PyErr_SetString(PyExc_TypeError, "gobject.IOChannel.writelines must"
                             " be sequence/iterator of strings");
             Py_DECREF(iter);
             return NULL;
         }
-        PYGLIB_PyUnicode_AsStringAndSize(value, &buf, &buf_len);
+        PyString_AsStringAndSize(value, &buf, &buf_len);
         pyglib_unblock_threads();
         status = g_io_channel_write_chars(self->channel, buf, buf_len, &count, &error);
         pyglib_unblock_threads();
@@ -325,10 +321,15 @@ normal_exit:
 }
 
 static PyObject*
-py_io_channel_flush(PyGIOChannel* self)
+py_io_channel_flush(PyGIOChannel* self, PyObject *args, PyObject *kwargs)
 {
+    static char *kwlist[] = { NULL };
     GError* error = NULL;
     GIOStatus status;
+
+    if (!PyArg_ParseTupleAndKeywords(args, kwargs, ":gobject.IOChannel.flush",
+                                     kwlist))
+        return NULL;
 	
     pyglib_unblock_threads();
     status = g_io_channel_flush(self->channel, &error);
@@ -336,7 +337,7 @@ py_io_channel_flush(PyGIOChannel* self)
     if (pyglib_error_check(&error))
 	return NULL;
 	
-    return PYGLIB_PyLong_FromLong(status);
+    return PyInt_FromLong(status);
 }
 
 static PyObject*
@@ -347,7 +348,7 @@ py_io_channel_set_flags(PyGIOChannel* self, PyObject *args, PyObject *kwargs)
     GIOStatus status;
     GError* error = NULL;
 
-    if (!PyArg_ParseTupleAndKeywords(args, kwargs, "i:glib.IOChannel.set_flags",
+    if (!PyArg_ParseTupleAndKeywords(args, kwargs, "i:gobject.IOChannel.set_flags",
                                      kwlist, &flags))
         return NULL;
 	
@@ -355,19 +356,35 @@ py_io_channel_set_flags(PyGIOChannel* self, PyObject *args, PyObject *kwargs)
     if (pyglib_error_check(&error))
 	return NULL;
 	
-    return PYGLIB_PyLong_FromLong(status);
+    return PyInt_FromLong(status);
 }
 
 static PyObject*
-py_io_channel_get_flags(PyGIOChannel* self)
+py_io_channel_get_flags(PyGIOChannel* self, PyObject *args, PyObject *kwargs)
 {
-    return PYGLIB_PyLong_FromLong(g_io_channel_get_flags(self->channel));
+    static char *kwlist[] = { NULL };
+    GIOFlags flags;
+
+    if (!PyArg_ParseTupleAndKeywords(args, kwargs, ":gobject.IOChannel.get_flags",
+                                     kwlist))
+        return NULL;
+	
+    flags = g_io_channel_get_flags(self->channel);
+    return PyInt_FromLong(flags);
 }
 
 static PyObject*
-py_io_channel_get_buffer_condition(PyGIOChannel* self)
+py_io_channel_get_buffer_condition(PyGIOChannel* self, PyObject *args, PyObject *kwargs)
 {
-    return PYGLIB_PyLong_FromLong(g_io_channel_get_buffer_condition(self->channel));
+    static char *kwlist[] = { NULL };
+    GIOCondition cond;
+
+    if (!PyArg_ParseTupleAndKeywords(args, kwargs, ":gobject.IOChannel.get_buffer_condition",
+                                     kwlist))
+        return NULL;
+	
+    cond = g_io_channel_get_buffer_condition(self->channel);
+    return PyInt_FromLong(cond);
 }
 
 static PyObject*
@@ -376,7 +393,7 @@ py_io_channel_set_close_on_unref(PyGIOChannel* self, PyObject *args, PyObject *k
     static char *kwlist[] = { "do_close", NULL };
     PyObject *do_close;
 
-    if (!PyArg_ParseTupleAndKeywords(args, kwargs, "O:glib.IOChannel.set_close_on_unref",
+    if (!PyArg_ParseTupleAndKeywords(args, kwargs, "O:gobject.IOChannel.set_close_on_unref",
                                      kwlist, &do_close))
         return NULL;
 	
@@ -386,7 +403,7 @@ py_io_channel_set_close_on_unref(PyGIOChannel* self, PyObject *args, PyObject *k
 }
 
 static PyObject*
-py_io_channel_get_close_on_unref(PyGIOChannel* self)
+py_io_channel_get_close_on_unref(PyGIOChannel* self, PyObject *args, PyObject *kwargs)
 {
     if (g_io_channel_get_close_on_unref(self->channel)) {
         Py_INCREF(Py_True);
@@ -460,7 +477,7 @@ py_io_channel_add_watch(PyObject *self, PyObject *args, PyObject *kwargs)
     PyGIOWatchData *data;
 
     if (!PyArg_ParseTupleAndKeywords(args, kwargs,
-                                     "iO|Oi:glib.IOChannel.add_watch",
+                                     "iO|Oi:gobject.IOChannel.add_watch",
                                      kwlist, &condition, &callback,
                                      &user_data, &priority))
         return NULL;
@@ -498,7 +515,7 @@ py_io_channel_win32_poll(PyObject *self, PyObject *args, PyObject *kwargs)
     gint result;
 
     if (!PyArg_ParseTupleAndKeywords(args, kwargs,
-                                     "O!|i:glib.IOChannel.win32_poll",
+                                     "O!|i:gobject.IOChannel.win32_poll",
                                      kwlist, &PyList_Type, &pyfds, &timeout))
         return NULL;
 
@@ -507,7 +524,7 @@ py_io_channel_win32_poll(PyObject *self, PyObject *args, PyObject *kwargs)
     for (i = 0; i < len; ++i) {
         pyfd = PyList_GET_ITEM(pyfds, i);
         if (!PyObject_TypeCheck(pyfd, &PyGPollFD_Type)) {
-            PyErr_SetString(PyExc_TypeError, "'fds' must be a list of glib.PollFD objects");
+            PyErr_SetString(PyExc_TypeError, "'fds' must be a list of gobject.PollFD objects");
             return NULL;
         }
         pollfd[i] = ((PyGPollFD *) pyfd)->pollfd;
@@ -518,7 +535,7 @@ py_io_channel_win32_poll(PyObject *self, PyObject *args, PyObject *kwargs)
         pyfd = PyList_GET_ITEM(pyfds, i);
         ((PyGPollFD *) pyfd)->pollfd = pollfd[i];
     }
-    return PYGLIB_PyLong_FromLong(result);
+    return PyInt_FromLong(result);
 }
 
 static PyObject *
@@ -530,7 +547,7 @@ py_io_channel_win32_make_pollfd(PyObject *self, PyObject *args, PyObject *kwargs
     PyGPollFD *pypollfd;
 
     if (!PyArg_ParseTupleAndKeywords(args, kwargs,
-                                     "i:glib.IOChannel.win32_make_pollfd",
+                                     "i:gobject.IOChannel.win32_make_pollfd",
                                      kwlist, &condition))
         return NULL;
 
@@ -554,7 +571,7 @@ py_io_channel_read_line(PyGIOChannel* self, PyObject *args, PyObject *kwargs)
     gint size_hint = -1;
     GIOStatus status;
 
-    if (!PyArg_ParseTupleAndKeywords(args, kwargs, "|i:glib.IOChannel.readline", kwlist,
+    if (!PyArg_ParseTupleAndKeywords(args, kwargs, "|i:gobject.IOChannel.readline", kwlist,
                                      &size_hint))
         return NULL;
 
@@ -562,7 +579,7 @@ py_io_channel_read_line(PyGIOChannel* self, PyObject *args, PyObject *kwargs)
                                     &terminator_pos, &error);
     if (pyglib_error_check(&error))
         return NULL;
-    ret_obj = PYGLIB_PyUnicode_FromStringAndSize(str_return, length);
+    ret_obj = PyString_FromStringAndSize(str_return, length);
     g_free(str_return);
     return ret_obj;
 }
@@ -579,7 +596,7 @@ py_io_channel_read_lines(PyGIOChannel* self, PyObject *args, PyObject *kwargs)
     GIOStatus status = G_IO_STATUS_NORMAL;
     PyObject *list;
 
-    if (!PyArg_ParseTupleAndKeywords(args, kwargs, "|i:glib.IOChannel.readlines", kwlist,
+    if (!PyArg_ParseTupleAndKeywords(args, kwargs, "|i:gobject.IOChannel.readlines", kwlist,
                                      &size_hint))
         return NULL;
 
@@ -591,7 +608,7 @@ py_io_channel_read_lines(PyGIOChannel* self, PyObject *args, PyObject *kwargs)
             Py_DECREF(line);
             return NULL;
         }
-        line = PYGLIB_PyUnicode_FromStringAndSize(str_return, length);
+        line = PyString_FromStringAndSize(str_return, length);
         g_free(str_return);
         if (PyList_Append(list, line)) {
             Py_DECREF(line);
@@ -613,7 +630,7 @@ py_io_channel_seek(PyGIOChannel* self, PyObject *args, PyObject *kwargs)
     GSeekType seek_type;
     GError* error = NULL;
 
-    if (!PyArg_ParseTupleAndKeywords(args, kwargs, "L|i:glib.IOChannel.seek",
+    if (!PyArg_ParseTupleAndKeywords(args, kwargs, "L|i:gobject.IOChannel.seek",
                                      kwlist, &offset, &whence))
         return NULL;
 
@@ -632,7 +649,7 @@ py_io_channel_seek(PyGIOChannel* self, PyObject *args, PyObject *kwargs)
     if (pyglib_error_check(&error))
 	return NULL;
 	
-    return PYGLIB_PyLong_FromLong(status);
+    return PyInt_FromLong(status);
 }
 
 #if 0 // Not wrapped
@@ -667,29 +684,29 @@ static PyMemberDef py_io_channel_members[] = {
 };
 
 static PyMethodDef py_io_channel_methods[] = {
-    { "close", (PyCFunction)py_io_channel_shutdown, METH_VARARGS|METH_KEYWORDS },
-    { "flush", (PyCFunction)py_io_channel_flush, METH_NOARGS },
-    { "set_encoding", (PyCFunction)py_io_channel_set_encoding, METH_VARARGS|METH_KEYWORDS },
-    { "get_encoding", (PyCFunction)py_io_channel_get_encoding, METH_NOARGS },
-    { "set_buffered", (PyCFunction)py_io_channel_set_buffered, METH_VARARGS|METH_KEYWORDS },
-    { "get_buffered", (PyCFunction)py_io_channel_get_buffered, METH_NOARGS },
-    { "set_buffer_size", (PyCFunction)py_io_channel_set_buffer_size, METH_VARARGS|METH_KEYWORDS },
-    { "get_buffer_size", (PyCFunction)py_io_channel_get_buffer_size, METH_NOARGS },
-    { "read", (PyCFunction)py_io_channel_read_chars, METH_VARARGS|METH_KEYWORDS },
-    { "readline", (PyCFunction)py_io_channel_read_line, METH_VARARGS|METH_KEYWORDS },
-    { "readlines", (PyCFunction)py_io_channel_read_lines, METH_VARARGS|METH_KEYWORDS },
-    { "write", (PyCFunction)py_io_channel_write_chars, METH_VARARGS|METH_KEYWORDS },
-    { "writelines", (PyCFunction)py_io_channel_write_lines, METH_VARARGS|METH_KEYWORDS },
-    { "set_flags", (PyCFunction)py_io_channel_set_flags, METH_VARARGS|METH_KEYWORDS },
-    { "get_flags", (PyCFunction)py_io_channel_get_flags, METH_NOARGS },
-    { "get_buffer_condition", (PyCFunction)py_io_channel_get_buffer_condition, METH_NOARGS },
-    { "set_close_on_unref", (PyCFunction)py_io_channel_set_close_on_unref, METH_VARARGS | METH_KEYWORDS },
-    { "get_close_on_unref", (PyCFunction)py_io_channel_get_close_on_unref, METH_NOARGS },
-    { "add_watch", (PyCFunction)py_io_channel_add_watch, METH_VARARGS|METH_KEYWORDS },
-    { "seek", (PyCFunction)py_io_channel_seek, METH_VARARGS|METH_KEYWORDS },
+    { "close", (PyCFunction)py_io_channel_shutdown, METH_KEYWORDS },
+    { "flush", (PyCFunction)py_io_channel_flush, METH_KEYWORDS },
+    { "set_encoding", (PyCFunction)py_io_channel_set_encoding, METH_KEYWORDS },
+    { "get_encoding", (PyCFunction)py_io_channel_get_encoding, METH_KEYWORDS },
+    { "set_buffered", (PyCFunction)py_io_channel_set_buffered, METH_KEYWORDS },
+    { "get_buffered", (PyCFunction)py_io_channel_get_buffered, METH_KEYWORDS },
+    { "set_buffer_size", (PyCFunction)py_io_channel_set_buffer_size, METH_KEYWORDS },
+    { "get_buffer_size", (PyCFunction)py_io_channel_get_buffer_size, METH_KEYWORDS },
+    { "read", (PyCFunction)py_io_channel_read_chars, METH_KEYWORDS },
+    { "readline", (PyCFunction)py_io_channel_read_line, METH_KEYWORDS },
+    { "readlines", (PyCFunction)py_io_channel_read_lines, METH_KEYWORDS },
+    { "write", (PyCFunction)py_io_channel_write_chars, METH_KEYWORDS },
+    { "writelines", (PyCFunction)py_io_channel_write_lines, METH_KEYWORDS },
+    { "set_flags", (PyCFunction)py_io_channel_set_flags, METH_KEYWORDS },
+    { "get_flags", (PyCFunction)py_io_channel_get_flags, METH_KEYWORDS },
+    { "get_buffer_condition", (PyCFunction)py_io_channel_get_buffer_condition, METH_KEYWORDS },
+    { "set_close_on_unref", (PyCFunction)py_io_channel_set_close_on_unref, METH_NOARGS },
+    { "get_close_on_unref", (PyCFunction)py_io_channel_get_close_on_unref, METH_KEYWORDS },
+    { "add_watch", (PyCFunction)py_io_channel_add_watch, METH_KEYWORDS },
+    { "seek", (PyCFunction)py_io_channel_seek, METH_KEYWORDS },
 #ifdef G_OS_WIN32
-    { "win32_make_pollfd", (PyCFunction)py_io_channel_win32_make_pollfd, METH_VARARGS | METH_KEYWORDS },
-    { "win32_poll", (PyCFunction)py_io_channel_win32_poll, METH_VARARGS|METH_KEYWORDS|METH_STATIC },
+    { "win32_make_pollfd", (PyCFunction)py_io_channel_win32_make_pollfd, METH_KEYWORDS },
+    { "win32_poll", (PyCFunction)py_io_channel_win32_poll, METH_KEYWORDS|METH_STATIC },
 #endif
     { NULL, NULL, 0 }
 };
@@ -714,7 +731,7 @@ py_io_channel_init(PyGIOChannel *self, PyObject *args, PyObject *kwargs)
 #ifdef G_OS_WIN32
                                      "I"
 #endif
-                                     ":glib.IOChannel.__init__",
+                                     ":gobject.IOChannel.__init__",
                                      kwlist, &fd, &filename, &mode
 #ifdef G_OS_WIN32
                                      , &hwnd
@@ -747,18 +764,55 @@ py_io_channel_init(PyGIOChannel *self, PyObject *args, PyObject *kwargs)
     return 0;
 }
 
+
+PyTypeObject PyGIOChannel_Type = {
+    PyObject_HEAD_INIT(NULL)
+    0,					/* ob_size */
+    "gobject.IOChannel",		/* tp_name */
+    sizeof(PyGIOChannel),		/* tp_basicsize */
+    0,					/* tp_itemsize */
+    /* methods */
+    (destructor)py_io_channel_dealloc,	/* tp_dealloc */
+    (printfunc)0,			/* tp_print */
+    (getattrfunc)NULL,             	/* tp_getattr */
+    (setattrfunc)0,			/* tp_setattr */
+    (cmpfunc)py_io_channel_compare,	/* tp_compare */
+    (reprfunc)0,			/* tp_repr */
+    0,					/* tp_as_number */
+    0,					/* tp_as_sequence */
+    0,					/* tp_as_mapping */
+    (hashfunc)py_io_channel_hash,	/* tp_hash */
+    (ternaryfunc)0,			/* tp_call */
+    (reprfunc)0,			/* tp_str */
+    (getattrofunc)0,			/* tp_getattro */
+    (setattrofunc)0,			/* tp_setattro */
+    0,					/* tp_as_buffer */
+    Py_TPFLAGS_DEFAULT,			/* tp_flags */
+    NULL, /* Documentation string */
+    (traverseproc)0,			/* tp_traverse */
+    (inquiry)0,				/* tp_clear */
+    (richcmpfunc)0,			/* tp_richcompare */
+    0,					/* tp_weaklistoffset */
+    (getiterfunc)py_io_channel_get_iter,/* tp_iter */
+    (iternextfunc)py_io_channel_next,   /* tp_iternext */
+    py_io_channel_methods,		/* tp_methods */
+    py_io_channel_members,		/* tp_members */
+    NULL,				/* tp_getset */
+    (PyTypeObject *)0,			/* tp_base */
+    (PyObject *)0,			/* tp_dict */
+    0,					/* tp_descr_get */
+    0,					/* tp_descr_set */
+    0,					/* tp_dictoffset */
+    (initproc)py_io_channel_init,	/* tp_init */
+    (allocfunc)0,			/* tp_alloc */
+    (newfunc)0,				/* tp_new */
+    0,					/* tp_free */
+    (inquiry)0,				/* tp_is_gc */
+    (PyObject *)0,			/* tp_bases */
+};
+
 void
 pyglib_iochannel_register_types(PyObject *d)
 {
-    PyGIOChannel_Type.tp_init = (initproc)py_io_channel_init;
-    PyGIOChannel_Type.tp_dealloc = (destructor)py_io_channel_dealloc;
-    PyGIOChannel_Type.tp_flags = Py_TPFLAGS_DEFAULT;
-    PyGIOChannel_Type.tp_members = py_io_channel_members;
-    PyGIOChannel_Type.tp_methods = py_io_channel_methods;
-    PyGIOChannel_Type.tp_hash = (hashfunc)py_io_channel_hash;
-    PyGIOChannel_Type.tp_richcompare = (richcmpfunc)py_io_channel_richcompare;
-    PyGIOChannel_Type.tp_iter = (getiterfunc)py_io_channel_get_iter;
-    PyGIOChannel_Type.tp_iternext = (iternextfunc)py_io_channel_next;
-
     PYGLIB_REGISTER_TYPE(d, PyGIOChannel_Type, "IOChannel");
 }
