@@ -19,7 +19,7 @@
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
  * USA
  */
 
@@ -57,10 +57,6 @@ typedef struct
     PyObject *obj;
 } PyGRealSource;
 
-/* glib.Source */
-
-PYGLIB_DEFINE_TYPE("glib.Source", PyGSource_Type, PyGSource)
-
 static PyObject *
 source_repr(PyGSource *self, const char *type)
 {
@@ -82,7 +78,7 @@ source_repr(PyGSource *self, const char *type)
 	g_snprintf(buf, sizeof(buf), "<%s glib source at 0x%lx>",
 		   desc, (long) self);
 
-    return PYGLIB_PyUnicode_FromString(buf);
+    return PyString_FromString(buf);
 }
 
 static PyObject *
@@ -109,7 +105,7 @@ pyg_source_attach(PyGSource *self, PyObject *args, PyObject *kwargs)
     }
 
     id = g_source_attach(self->source, context);
-    return PYGLIB_PyLong_FromLong(id);
+    return PyInt_FromLong(id);
 }
 
 static PyObject *
@@ -182,7 +178,7 @@ pyg_source_get_context(PyGSource *self)
     context = g_source_get_context(self->source);
 
     if (context) {
-	return pyg_main_context_new(context);
+	return pyglib_main_context_new(context);
     } else {
 	Py_INCREF(Py_None);
 	return Py_None;
@@ -255,12 +251,12 @@ pyg_source_get_current_time(PyGSource *self)
 }
 
 static PyMethodDef pyg_source_methods[] = {
-    { "attach", (PyCFunction)pyg_source_attach, METH_VARARGS|METH_KEYWORDS },
+    { "attach", (PyCFunction)pyg_source_attach, METH_KEYWORDS },
     { "destroy", (PyCFunction)pyg_source_destroy, METH_NOARGS },
     { "set_callback", (PyCFunction)pyg_source_set_callback, METH_VARARGS },
     { "get_context", (PyCFunction)pyg_source_get_context, METH_NOARGS },
     { "add_poll", (PyCFunction)pyg_source_add_poll, METH_KEYWORDS },
-    { "remove_poll", (PyCFunction)pyg_source_remove_poll, METH_VARARGS|METH_KEYWORDS },
+    { "remove_poll", (PyCFunction)pyg_source_remove_poll, METH_KEYWORDS },
     { "get_current_time", (PyCFunction)pyg_source_get_current_time, METH_NOARGS },
     { NULL, NULL, 0 }
 };
@@ -283,7 +279,7 @@ pyg_source_get_priority(PyGSource *self, void *closure)
 {
     CHECK_DESTROYED(self, NULL);
 
-    return PYGLIB_PyLong_FromLong(g_source_get_priority(self->source));
+    return PyInt_FromLong(g_source_get_priority(self->source));
 }
 
 static int
@@ -296,12 +292,12 @@ pyg_source_set_priority(PyGSource *self, PyObject *value, void *closure)
 	return -1;
     }
 
-    if (!PYGLIB_PyLong_Check(value)) {
+    if (!PyInt_Check(value)) {
 	PyErr_SetString(PyExc_TypeError, "type mismatch");
 	return -1;
     }
 
-    g_source_set_priority(self->source, PYGLIB_PyLong_AsLong(value));
+    g_source_set_priority(self->source, PyInt_AsLong(value));
 
     return 0;
 }
@@ -339,7 +335,7 @@ pyg_source_get_id(PyGSource *self, void *closure)
 	return NULL;
     }
 
-    return PYGLIB_PyLong_FromLong(g_source_get_id(self->source));
+    return PyInt_FromLong(g_source_get_id(self->source));
 }
 
 static PyGetSetDef pyg_source_getsets[] = {
@@ -387,12 +383,10 @@ pyg_source_clear(PyGSource *self)
 static void
 pyg_source_dealloc(PyGSource *self)
 {
-    /* Must be done first, so that there is no chance of Python's GC being
-     * called while tracking this half-deallocated object */
-    PyObject_GC_UnTrack((PyObject *)self);
-
     PyObject_ClearWeakRefs((PyObject *)self);
 
+    PyObject_GC_UnTrack((PyObject *)self);
+
     pyg_source_clear(self);
 
     PyObject_GC_Del(self);
@@ -428,7 +422,7 @@ pyg_source_prepare(GSource *source, gint *timeout)
     }
 
     ret = PyObject_IsTrue(PyTuple_GET_ITEM(t, 0));
-	*timeout = PYGLIB_PyLong_AsLong(PyTuple_GET_ITEM(t, 1));
+	*timeout = PyInt_AsLong(PyTuple_GET_ITEM(t, 1));
 
 	if (*timeout == -1 && PyErr_Occurred()) {
 	    ret = FALSE;
@@ -564,9 +558,51 @@ pyg_source_free(PyObject *op)
     PyObject_GC_Del(op);
 }
 
-/* glib.Idle */
-
-PYGLIB_DEFINE_TYPE("glib.Idle", PyGIdle_Type, PyGSource)
+PyTypeObject PyGSource_Type = {
+    PyObject_HEAD_INIT(NULL)
+    0,					/* ob_size */
+    "gobject.Source",			/* tp_name */
+    sizeof(PyGSource),			/* tp_basicsize */
+    0,					/* tp_itemsize */
+    (destructor)pyg_source_dealloc,	/* tp_dealloc */
+    (printfunc)0,			/* tp_print */
+    (getattrfunc)0,			/* tp_getattr */
+    (setattrfunc)0,			/* tp_setattr */
+    (cmpfunc)0,				/* tp_compare */
+    (reprfunc)pyg_source_repr,		/* tp_repr */
+    0,					/* tp_as_number */
+    0,					/* tp_as_sequence */
+    0,					/* tp_as_mapping */
+    (hashfunc)0,			/* tp_hash */
+    (ternaryfunc)0,			/* tp_call */
+    (reprfunc)0,			/* tp_str */
+    (getattrofunc)0,			/* tp_getattro */
+    (setattrofunc)0,			/* tp_setattro */
+    0,					/* tp_as_buffer */
+    Py_TPFLAGS_DEFAULT | Py_TPFLAGS_BASETYPE |
+      Py_TPFLAGS_HAVE_GC,		/* tp_flags */
+    NULL,				/* tp_doc */
+    (traverseproc)pyg_source_traverse,	/* tp_traverse */
+    (inquiry)pyg_source_clear,		/* tp_clear */
+    (richcmpfunc)0,			/* tp_richcompare */
+    offsetof(PyGSource, weakreflist),	/* tp_weaklistoffset */
+    (getiterfunc)0,			/* tp_iter */
+    (iternextfunc)0,			/* tp_iternext */
+    pyg_source_methods,			/* tp_methods */
+    0,					/* tp_members */
+    pyg_source_getsets,			/* tp_getset */
+    (PyTypeObject *)0,			/* tp_base */
+    (PyObject *)0,			/* tp_dict */
+    0,					/* tp_descr_get */
+    0,					/* tp_descr_set */
+    offsetof(PyGSource, inst_dict),	/* tp_dictoffset */
+    (initproc)pyg_source_init,		/* tp_init */
+    (allocfunc)0,			/* tp_alloc */
+    (newfunc)0,				/* tp_new */
+    (freefunc)pyg_source_free,		/* tp_free */
+    (inquiry)0,				/* tp_is_gc */
+    (PyObject *)0,			/* tp_bases */
+};
 
 static PyObject *
 pyg_idle_repr(PyGSource *self)
@@ -581,7 +617,7 @@ pyg_idle_init(PyGSource *self, PyObject *args, PyObject *kwargs)
     gint priority = G_PRIORITY_DEFAULT_IDLE;
 
     if (!PyArg_ParseTupleAndKeywords(args, kwargs,
-				     "|i:glib.Idle.__init__", kwlist,
+				     "|i:gobject.Idle.__init__", kwlist,
 				     &priority))
 	return -1;
 
@@ -598,9 +634,50 @@ pyg_idle_init(PyGSource *self, PyObject *args, PyObject *kwargs)
     return 0;
 }
 
-/* glib.Timeout */
-
-PYGLIB_DEFINE_TYPE("glib.Timeout", PyGTimeout_Type, PyGSource)
+PyTypeObject PyGIdle_Type = {
+    PyObject_HEAD_INIT(NULL)
+    0,					/* ob_size */
+    "gobject.Idle",			/* tp_name */
+    sizeof(PyGSource),			/* tp_basicsize */
+    0,					/* tp_itemsize */
+    (destructor)0,			/* tp_dealloc */
+    (printfunc)0,			/* tp_print */
+    (getattrfunc)0,			/* tp_getattr */
+    (setattrfunc)0,			/* tp_setattr */
+    (cmpfunc)0,				/* tp_compare */
+    (reprfunc)pyg_idle_repr,		/* tp_repr */
+    0,					/* tp_as_number */
+    0,					/* tp_as_sequence */
+    0,					/* tp_as_mapping */
+    (hashfunc)0,			/* tp_hash */
+    (ternaryfunc)0,			/* tp_call */
+    (reprfunc)0,			/* tp_str */
+    (getattrofunc)0,			/* tp_getattro */
+    (setattrofunc)0,			/* tp_setattro */
+    0,					/* tp_as_buffer */
+    Py_TPFLAGS_DEFAULT | Py_TPFLAGS_BASETYPE,		/* tp_flags */
+    NULL,				/* tp_doc */
+    (traverseproc)0,			/* tp_traverse */
+    (inquiry)0,				/* tp_clear */
+    (richcmpfunc)0,			/* tp_richcompare */
+    0,					/* tp_weaklistoffset */
+    (getiterfunc)0,			/* tp_iter */
+    (iternextfunc)0,			/* tp_iternext */
+    NULL,				/* tp_methods */
+    NULL,				/* tp_members */
+    NULL,				/* tp_getset */
+    (PyTypeObject *)&PyGSource_Type,	/* tp_base */
+    (PyObject *)0,			/* tp_dict */
+    0,					/* tp_descr_get */
+    0,					/* tp_descr_set */
+    0,					/* tp_dictoffset */
+    (initproc)pyg_idle_init,		/* tp_init */
+    (allocfunc)0,			/* tp_alloc */
+    (newfunc)0,				/* tp_new */
+    (freefunc)0,			/* tp_free */
+    (inquiry)0,				/* tp_is_gc */
+    (PyObject *)0,			/* tp_bases */
+};
 
 static PyObject *
 pyg_timeout_repr(PyGSource *self)
@@ -616,7 +693,7 @@ pyg_timeout_init(PyGSource *self, PyObject *args, PyObject *kwargs)
     guint interval;
 
     if (!PyArg_ParseTupleAndKeywords(args, kwargs,
-				     "I|i:glib.Timeout.__init__", kwlist,
+				     "I|i:gobject.Timeout.__init__", kwlist,
 				     &interval, &priority))
 	return -1;
 
@@ -633,14 +710,55 @@ pyg_timeout_init(PyGSource *self, PyObject *args, PyObject *kwargs)
     return 0;
 }
 
-/* glib.PollFD */
-
-PYGLIB_DEFINE_TYPE("glib.PollFD", PyGPollFD_Type, PyGPollFD)
+PyTypeObject PyGTimeout_Type = {
+    PyObject_HEAD_INIT(NULL)
+    0,					/* ob_size */
+    "gobject.Timeout",			/* tp_name */
+    sizeof(PyGSource),			/* tp_basicsize */
+    0,					/* tp_itemsize */
+    (destructor)0,			/* tp_dealloc */
+    (printfunc)0,			/* tp_print */
+    (getattrfunc)0,			/* tp_getattr */
+    (setattrfunc)0,			/* tp_setattr */
+    (cmpfunc)0,				/* tp_compare */
+    (reprfunc)pyg_timeout_repr,		/* tp_repr */
+    0,					/* tp_as_number */
+    0,					/* tp_as_sequence */
+    0,					/* tp_as_mapping */
+    (hashfunc)0,			/* tp_hash */
+    (ternaryfunc)0,			/* tp_call */
+    (reprfunc)0,			/* tp_str */
+    (getattrofunc)0,			/* tp_getattro */
+    (setattrofunc)0,			/* tp_setattro */
+    0,					/* tp_as_buffer */
+    Py_TPFLAGS_DEFAULT | Py_TPFLAGS_BASETYPE,		/* tp_flags */
+    NULL,				/* tp_doc */
+    (traverseproc)0,			/* tp_traverse */
+    (inquiry)0,				/* tp_clear */
+    (richcmpfunc)0,			/* tp_richcompare */
+    0,					/* tp_weaklistoffset */
+    (getiterfunc)0,			/* tp_iter */
+    (iternextfunc)0,			/* tp_iternext */
+    NULL,				/* tp_methods */
+    NULL,				/* tp_members */
+    NULL,				/* tp_getset */
+    (PyTypeObject *)&PyGSource_Type,	/* tp_base */
+    (PyObject *)0,			/* tp_dict */
+    0,					/* tp_descr_get */
+    0,					/* tp_descr_set */
+    0,					/* tp_dictoffset */
+    (initproc)pyg_timeout_init,		/* tp_init */
+    (allocfunc)0,			/* tp_alloc */
+    (newfunc)0,				/* tp_new */
+    (freefunc)0,			/* tp_free */
+    (inquiry)0,				/* tp_is_gc */
+    (PyObject *)0,			/* tp_bases */
+};
 
 static PyMemberDef pyg_poll_fd_members[] = {
-    { "fd",      T_INT,    offsetof(PyGPollFD, pollfd.fd),      READONLY },
-    { "events",  T_USHORT, offsetof(PyGPollFD, pollfd.events),  READONLY },
-    { "revents", T_USHORT, offsetof(PyGPollFD, pollfd.revents), READONLY },
+    { "fd",      T_INT,    offsetof(PyGPollFD, pollfd.fd),      RO },
+    { "events",  T_USHORT, offsetof(PyGPollFD, pollfd.events),  RO },
+    { "revents", T_USHORT, offsetof(PyGPollFD, pollfd.revents), RO },
     { NULL, 0, 0, 0 }
 };
 
@@ -654,9 +772,9 @@ pyg_poll_fd_dealloc(PyGPollFD *self)
 static PyObject *
 pyg_poll_fd_repr(PyGPollFD *self)
 {
-    return PYGLIB_PyUnicode_FromFormat("<GPollFD %d (%d) at 0x%lx>",
-				 self->pollfd.fd, self->pollfd.events,
-				 (long)self);
+    return PyString_FromFormat("<GPollFD %d (%d) at 0x%lx>",
+			       self->pollfd.fd, self->pollfd.events,
+			       (long)self);
 }
 
 static int
@@ -668,7 +786,7 @@ pyg_poll_fd_init(PyGPollFD *self, PyObject *args, PyObject *kwargs)
     gushort events;
 
     if (!PyArg_ParseTupleAndKeywords(args, kwargs,
-				     "OH:glib.PollFD.__init__", kwlist,
+				     "OH:gobject.PollFD.__init__", kwlist,
 				     &o, &events))
 	return -1;
 
@@ -686,40 +804,56 @@ pyg_poll_fd_init(PyGPollFD *self, PyObject *args, PyObject *kwargs)
     return 0;
 }
 
+PyTypeObject PyGPollFD_Type = {
+    PyObject_HEAD_INIT(NULL)
+    0,					/* ob_size */
+    "gobject.PollFD",			/* tp_name */
+    sizeof(PyGPollFD),			/* tp_basicsize */
+    0,					/* tp_itemsize */
+    (destructor)pyg_poll_fd_dealloc,	/* tp_dealloc */
+    (printfunc)0,			/* tp_print */
+    (getattrfunc)0,			/* tp_getattr */
+    (setattrfunc)0,			/* tp_setattr */
+    (cmpfunc)0,				/* tp_compare */
+    (reprfunc)pyg_poll_fd_repr,		/* tp_repr */
+    0,					/* tp_as_number */
+    0,					/* tp_as_sequence */
+    0,					/* tp_as_mapping */
+    (hashfunc)0,			/* tp_hash */
+    (ternaryfunc)0,			/* tp_call */
+    (reprfunc)0,			/* tp_str */
+    (getattrofunc)0,			/* tp_getattro */
+    (setattrofunc)0,			/* tp_setattro */
+    0,					/* tp_as_buffer */
+    Py_TPFLAGS_DEFAULT,			/* tp_flags */
+    NULL,				/* tp_doc */
+    (traverseproc)0,			/* tp_traverse */
+    (inquiry)0,				/* tp_clear */
+    (richcmpfunc)0,			/* tp_richcompare */
+    0,					/* tp_weaklistoffset */
+    (getiterfunc)0,			/* tp_iter */
+    (iternextfunc)0,			/* tp_iternext */
+    0,					/* tp_methods */
+    pyg_poll_fd_members,		/* tp_members */
+    0,					/* tp_getset */
+    (PyTypeObject *)0,			/* tp_base */
+    (PyObject *)0,			/* tp_dict */
+    0,					/* tp_descr_get */
+    0,					/* tp_descr_set */
+    0,					/* tp_dictoffset */
+    (initproc)pyg_poll_fd_init,		/* tp_init */
+    (allocfunc)0,			/* tp_alloc */
+    (newfunc)0,				/* tp_new */
+    (freefunc)0,			/* tp_free */
+    (inquiry)0,				/* tp_is_gc */
+    (PyObject *)0,			/* tp_bases */
+};
+
 void
 pyglib_source_register_types(PyObject *d)
 {
-    PyGSource_Type.tp_flags = (Py_TPFLAGS_DEFAULT |
-			       Py_TPFLAGS_BASETYPE |
-			       Py_TPFLAGS_HAVE_GC);
-    PyGSource_Type.tp_init = (initproc)pyg_source_init;
-    PyGSource_Type.tp_free = (freefunc)pyg_source_free;
-    PyGSource_Type.tp_dealloc = (destructor)pyg_source_dealloc;
-    PyGSource_Type.tp_methods = pyg_source_methods;
-    PyGSource_Type.tp_repr = (reprfunc)pyg_source_repr;
-    PyGSource_Type.tp_traverse = (traverseproc)pyg_source_traverse;
-    PyGSource_Type.tp_clear = (inquiry)pyg_source_clear;
-    PyGSource_Type.tp_getset = pyg_source_getsets;
-    PyGSource_Type.tp_weaklistoffset = offsetof(PyGSource, weakreflist);
-    PyGSource_Type.tp_dictoffset = offsetof(PyGSource, inst_dict);
     PYGLIB_REGISTER_TYPE(d, PyGSource_Type, "Source");
-
-    PyGIdle_Type.tp_repr = (reprfunc)pyg_idle_repr;
-    PyGIdle_Type.tp_flags = Py_TPFLAGS_DEFAULT | Py_TPFLAGS_BASETYPE;
-    PyGIdle_Type.tp_base = (PyTypeObject *)&PyGSource_Type;
-    PyGIdle_Type.tp_init = (initproc)pyg_idle_init;
     PYGLIB_REGISTER_TYPE(d, PyGIdle_Type, "Idle");
-
-    PyGTimeout_Type.tp_repr = (reprfunc)pyg_timeout_repr;
-    PyGTimeout_Type.tp_flags = Py_TPFLAGS_DEFAULT | Py_TPFLAGS_BASETYPE;
-    PyGTimeout_Type.tp_base = (PyTypeObject *)&PyGSource_Type;
-    PyGTimeout_Type.tp_init = (initproc)pyg_timeout_init;
     PYGLIB_REGISTER_TYPE(d, PyGTimeout_Type, "Timeout");
-
-    PyGPollFD_Type.tp_dealloc = (destructor)pyg_poll_fd_dealloc;
-    PyGPollFD_Type.tp_repr = (reprfunc)pyg_poll_fd_repr;
-    PyGPollFD_Type.tp_flags = Py_TPFLAGS_DEFAULT;
-    PyGPollFD_Type.tp_members = pyg_poll_fd_members;
-    PyGPollFD_Type.tp_init = (initproc)pyg_poll_fd_init;
     PYGLIB_REGISTER_TYPE(d, PyGPollFD_Type, "PollFD");
 }
