@@ -20,6 +20,8 @@
  * USA
  */
 
+#include <pyglib.h>
+
 #include "pygobject-private.h"
 
 /* -------------- __gtype__ objects ---------------------------- */
@@ -50,7 +52,7 @@ pyg_type_wrapper_repr(PyGTypeWrapper *self)
     const gchar *name = g_type_name(self->type);
 
     g_snprintf(buf, sizeof(buf), "<GType %s (%lu)>",
-	       name?name:"invalid", self->type);
+	       name?name:"invalid", (unsigned long int) self->type);
     return PyString_FromString(buf);
 }
 
@@ -1076,11 +1078,11 @@ pyg_closure_invalidate(gpointer data, GClosure *closure)
     PyGClosure *pc = (PyGClosure *)closure;
     PyGILState_STATE state;
 
-    state = pyg_gil_state_ensure();
+    state = pyglib_gil_state_ensure();
     Py_XDECREF(pc->callback);
     Py_XDECREF(pc->extra_args);
     Py_XDECREF(pc->swap_data);
-    pyg_gil_state_release(state);
+    pyglib_gil_state_release(state);
 
     pc->callback = NULL;
     pc->extra_args = NULL;
@@ -1100,7 +1102,7 @@ pyg_closure_marshal(GClosure *closure,
     PyObject *params, *ret;
     guint i;
 
-    state = pyg_gil_state_ensure();
+    state = pyglib_gil_state_ensure();
 
     /* construct Python tuple for the parameter values */
     params = PyTuple_New(n_param_values);
@@ -1148,7 +1150,7 @@ pyg_closure_marshal(GClosure *closure,
     
  out:
     Py_DECREF(params);
-    pyg_gil_state_release(state);
+    pyglib_gil_state_release(state);
 }
 
 /**
@@ -1241,7 +1243,7 @@ pyg_signal_class_closure_marshal(GClosure *closure,
     PyObject *params, *ret;
     guint i, len;
 
-    state = pyg_gil_state_ensure();
+    state = pyglib_gil_state_ensure();
     
     g_return_if_fail(invocation_hint != NULL);
     /* get the object passed as the first argument to the closure */
@@ -1267,7 +1269,7 @@ pyg_signal_class_closure_marshal(GClosure *closure,
     if (!method) {
 	PyErr_Clear();
 	Py_DECREF(object_wrapper);
-	pyg_gil_state_release(state);
+	pyglib_gil_state_release(state);
 	return;
     }
     Py_DECREF(object_wrapper);
@@ -1281,7 +1283,7 @@ pyg_signal_class_closure_marshal(GClosure *closure,
 	/* error condition */
 	if (!item) {
 	    Py_DECREF(params);
-	    pyg_gil_state_release(state);
+	    pyglib_gil_state_release(state);
 	    return;
 	}
 	PyTuple_SetItem(params, i - 1, item);
@@ -1308,7 +1310,7 @@ pyg_signal_class_closure_marshal(GClosure *closure,
 	PyErr_Print();
 	Py_DECREF(method);
 	Py_DECREF(params);
-	pyg_gil_state_release(state);
+	pyglib_gil_state_release(state);
 	return;
     }
     Py_DECREF(method);
@@ -1316,7 +1318,7 @@ pyg_signal_class_closure_marshal(GClosure *closure,
     if (return_value)
 	pyg_value_from_pyobject(return_value, ret);
     Py_DECREF(ret);
-    pyg_gil_state_release(state);
+    pyglib_gil_state_release(state);
 }
 
 /**
